==> q-4.6.tar.gz: q-4.6/src/qcmsgs.c <==

/*  Q eQuational Programming System
    Copyright (c) 1991-2002 by Albert Graef
    <ag@muwiinfa.geschichte.uni-mainz.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

char           *qcmsg[] = {

	"file not found",
	"error writing code file",
	"too many files",

	"syntax error",
	"error in declaration",
	"type `%s' already declared",
	"symbol `%s' already declared",
	"conflicting declarations for `%s'",
	"no public symbol `%s' in module `%s'",
	"conflicting imports for `%s'",
	"undeclared type `%s'",
	"incompatible types",
	"error in definition",
	"bad reference to anonymous variable",
	"open comment at end of file",
	"missing string terminator",
	"priority value out of range",

	"limb space overflow",
	"string space overflow",
	"symbol table overflow",
	"expression too complex",
	"code table overflow",
	"out of memory",

	"unknown module `%s'",
	"module name `%s' already in use",
	"cyclic import",
	"free variable on left-hand side of equation"
};

==> q-7.11.tar.gz: q-7.11/src/qcmsgs.c <==

/*  Q eQuational Programming System
    Copyright (c) 1991-2002 by Albert Graef
    <ag@muwiinfa.geschichte.uni-mainz.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

char           *qcmsg[] = {

	"file not found",
	"error writing code file",
	"too many files",

	"syntax error",
	"error in declaration",
	"unkown symbol in alias declaration",
	"type `%s' already declared",
	"symbol `%s' already declared",
	"conflicting declarations for `%s'",
	"unkown symbol `%s' in module `%s'",
	"conflicting imports for `%s'",
	"undeclared type `%s'",
	"incompatible types",
	"error in definition",
	"bad reference to anonymous variable",
	"type guard not permitted here",
	"open comment at end of file",
	"missing string terminator",
	"invalid character escape `%s'",
	"priority value out of range",
	"precedence value out of range",

	"limb space overflow",
	"string space overflow",
	"symbol table overflow",
	"expression too complex",
	"code table overflow",
	"out of memory",

	"unknown module `%s'",
	"module name `%s' already in use",
	"cyclic import",
	"free variable on left-hand side of equation",

	"undeclared variable symbol `%s'",
	"undeclared function symbol `%s'",
	"unqualified use of symbol `%s' in module `%s'",
	"overlap between virtual and nonvirtual constructors"
};
